@@ -2,14 +2,21 @@
 
 Inspired by `pass`.
 """
-
 import os
 
+version_file = os.path.join(os.path.dirname(__file__), "VERSION")
+if not os.path.exists(version_file):
+    version = "v0.0.0"
+else:
+    with open(version_file) as f:
+        version = f.read()
+version = version.lstrip("v")
+
 __author__ = "Patrick Schneeweis"
 __docformat__ = "markdown en"
 __license__ = "GPLv3+"
 __title__ = "pod-store"
-__version__ = "0.0.1"
+__version__ = version
 
 DEFAULT_STORE_PATH = os.path.join(os.path.expanduser("~"), ".pod-store")
 DEFAULT_PODCAST_DOWNLOADS_PATH = os.path.join(os.path.expanduser("~"), "Podcasts")
